@@ -169,7 +169,7 @@ sub reset {
 
 #########################################
 # Private output converter functions:
-sub _encode_hex { sprintf "%x", $_[0] }
+sub _encode_hex { sprintf "%0${_[1]}x", $_[0] }
 
 sub _encode_base64 {
   my ($res, $padding, $in) = ("", undef, $_[0]);
@@ -240,7 +240,7 @@ sub digest {
 }
 
 sub hexdigest {
-  _encode_hex($_[0]->digest)
+  _encode_hex($_[0]->digest, $_[0]->{width}/4)
 }
 
 sub b64digest {
@@ -314,31 +314,31 @@ sub crc32 { _cont($_[0],$_[1],@{$_typedef{crc32}}) }
 
 sub crc64 { _crc64($_[0],defined($_[1])?$_[1]:0) }
 
-sub crc_hex { _encode_hex &crc }
+sub crc_hex { _encode_hex(&crc,2) }
 
 sub crc_base64 { _encode_base64 &crc }
 
-sub crc8_hex { _encode_hex &crc8 }
+sub crc8_hex { _encode_hex(&crc8,2) }
 
 sub crc8_base64 { _encode_base64 &crc8 }
 
-sub crcccitt_hex { _encode_hex &crcccitt }
+sub crcccitt_hex { _encode_hex(&crcccitt,4) }
 
 sub crcccitt_base64 { _encode_base64 &crcccitt }
 
-sub crc16_hex { _encode_hex &crc16 }
+sub crc16_hex { _encode_hex(&crc16,4) }
 
 sub crc16_base64 { _encode_base64 &crc16 }
 
-sub crcopenpgparmor_hex { _encode_hex &crcopenpgparmor }
+sub crcopenpgparmor_hex { _encode_hex(&crcopenpgparmor,6) }
 
 sub crcopenpgparmor_base64 { _encode_base64 &crcopenpgparmor }
 
-sub crc32_hex { _encode_hex &crc32 }
+sub crc32_hex { _encode_hex(&crc32,8) }
 
 sub crc32_base64 { _encode_base64 &crc32 }
 
-sub crc64_hex { _encode_hex &crc64 }
+sub crc64_hex { _encode_hex(&crc64,16) }
 
 sub crc64_base64 { _encode_base64 &crc64 }
 
